Qurro

Loading Qurro plots; this might take a few seconds...
Color scheme
Bar width
Fit bar widths to a constant plot width?

Warning: The rank plot is currently using a bar width of less than one pixel per bar. This means that the image shown isn't necessarily going to be an accurate representation of the rank plot.

x-axis field
x-axis scale type
Color field
Color scale type
Categorical color scheme
Quantitative color scheme
Use boxplots for categorical data?
Draw borders on scatterplot points?
Exclude metadata fields from exported data?

Warning: Currently, ___ feature(s) are selected in both the numerator and denominator of the log-ratio. We strongly suggest you instead look at a log-ratio that doesn't contain common features in the numerator and denominator.

#### Numerator Features

#### Denominator Features

#### Autoselecting Features

Using the current ranking, select the top and bottom

#### Selecting Features by Filtering

Filter numerator to features where
Filter denominator to features where